REBOL [
	Title:  "REBOL Installer"
	Rights: "Copyright REBOL Technologies 1997-2005. All rights reserved."
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

;-- Check-Install ------------------------------------------------------------
;
;	This function must be done early enough that windows registry functions
;	are still available and the sandbox has not yet been established.
;
check-install: has [info] [
	switch/default system/options/install [
		uninstall [uninstall-rebol quit]
		reinstall [install-rebol quit]
		noinstall [] ; no-op
	][
		; User did not specify, so determine if we are installed:
		info: registered? "REBOL" form system/product ; [version home-dir data-dir] | none
		if not all [
			info
			tuple? info/1
			system/version <= info/1 ;>
			file? info/2
			system/options/home: info/2
			file? info/3
			view-root: info/3
		][
			; Registry entry is missing, invalid, or old. So, now determine if
			; the user has asked for REBOL to run bypassed (not installed).
			; Note: it's a permanent per-user flag as long as the sandbox exists.
			info: default-data-dir?
			either exists? info/bypass-install [
				;print "info!"
				view-root: dirize info
			][
				install-rebol quit
			]
		]
	]
]