REBOL [
	Title: "REBOL Mezzanine Functions: Input"
	Rights: "Copyright REBOL Technologies 1997-2002"
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

input: func [
	{Inputs a string from the console. New-line character is removed.}
	/hide "Mask input with a * character"
	/local console-port buffer char ignore ignore-chars
][
	either hide [
		console-port: open/binary [scheme: 'console]
		buffer: make string! 10
		ignore: make binary! 10
		ignore-chars: charset ["^(null)^(esc)"]
		while [
			wait console-port
			char: to-char first console-port
			(char <> newline) and (char <> #"^M")
		][
			any [
				all [char = #"^(back)"
					 either not empty? buffer [
						clear back tail buffer
						prin ["^(back) ^(back)"]
					] [true]
					  true
				]
				all [find ignore-chars char
					 read-io console-port ignore 3 ; suck up escape sequences
					 true
				]
				all [append buffer char
					 prin #"*"
					 false
				]
			]
		]
		 prin newline
		 close console-port
		 buffer
	] [ ; no hide
		pick system/ports/input 1
	]
]

ask: func [
	"Ask the user for input."
	question [series!] "Prompt to user"
	/hide "mask input with *"
][
	prin question
	trim either hide [input/hide] [input]
]

confirm: func [
	"Confirms a user choice." 
	[catch]
	question [series!] "Prompt to user"
	/with choices [string! block!] 
	/local response match-multiple
][
	match-multiple: func [choices][
		use [yes no][
			set [yes no] choices 
			if find yes response [return true]
			if find no  response [return false]
			return none
		]
	]
	if all [with 2 < length? choices][
		throw make error! reduce ['script 'invalid-arg mold choices] 
	]	 
	response: ask question
	if not with [choices: [["y" "yes"]["n" "no"]]]
	all [empty?	 choices return true]
	all [string?     choices return either find/match response choices [true][none]]
	all [2 > length? choices return either find/match response first choices [true][none]]
	all [2 = length? choices return match-multiple choices]
]

