REBOL [
	Title: "REBOL Mezzanine Functions: Web"
	Rights: "Copyright REBOL Technologies 1997-2002"
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

build-tag: func [
	"Generates a tag from a composed block."
	values [block!] "Block of parens to evaluate and other data."
	/local tag value-rule xml? name attribute value
][
	tag: make string! 7 * length? values
	value-rule: [
		set value issue! (value: mold value)
		| set value file! (value: replace/all copy value #" " "%20")
		| set value any-type!
	]
	xml?: false
	parse compose values [
		[
			set name ['?xml (xml?: true) | word!] (append tag name)
			any [
				set attribute [word! | url!] value-rule (
					repend tag [#" " attribute {="} value {"}]
				)
				| value-rule (repend tag [#" " value])
			]
			end (if xml? [append tag #"?"])
		]
		|
		[set name refinement! to end (tag: mold name)]
	]
	to tag! tag
]

build-markup: func [
	"Return markup text replacing <%tags%> with their evaluated results."
	content [string! file! url!]
	/quiet "Do not show errors in the output."
	/local out eval value
][
	content: either string? content [copy content][read content]
	out: make string! 126
	eval: func [val /local tmp] [
		either error? set/any 'tmp try [do val] [
			if not quiet [
				tmp: disarm :tmp
				append out reform ["***ERROR" tmp/id "in:" val] 
			]
		][
			if not unset? get/any 'tmp [append out :tmp]
		]
	]
	parse/all content [
		any [
			  end break
			;| "<%=" copy-rule (eval/lit value)
			| "<%" [copy value to "%>" 2 skip | copy value to end] (eval value)
			| copy value [to "<%" | to end] (append out value)
		]
	]
	out
]

decode-cgi: func [
	"Converts CGI argument string to a block of set-words and value strings."
	args [any-string!] "Starts at first argument word."
	/local block name value here tmp
][
	block: make block! 7
	parse/all args [
		any [
			copy name [to #"=" | to #"&" | to end] skip here: (
				if tmp: find name #"&" [
					here: skip here (offset? tmp name) - 2
					clear tmp
				]
				name: to-set-word dehex name ;Flash url-encodes names as well (even chars like #"-" or #"_")!
				; If new word, append it. If existing word, create block of values for it.
				either tmp: find block name [
					tmp: next tmp
					if not block? value: first tmp [
						change/only tmp reduce [value]
					]
					tmp: first tmp
				][
					append tmp: block name
				]
			) :here [
				[copy value to #"&" skip | copy value to end]
				(
					append tmp either none? value [copy ""][
						replace/all dehex replace/all value #"+" #" " crlf newline
					]
				)
			]
		]
		end
	]
	block
]


read-cgi: func [
	"Read CGI data from web server input stream. Return data as string."
	/limit size "Option to limit to this number of bytes"
	/local data buffer
][
	either system/options/cgi/request-method = "post" [
		data: make string! 1020
		buffer: make string! 16380
		while [positive? read-io system/ports/input buffer 16380][
			append data buffer
			clear buffer
			if all [limit (length? data) > size][
				do make error! reform [
					"read-cgi aborted - posting is too long:"
					length? data "limit:" size
				]
			]
		]
	][data: system/options/cgi/query-string] ; method = get
	any [data copy ""] ; string always returned
]
