REBOL [
	Title:  "REBOL/View: Visual Interface Dialect - Feelings"
	Author: "Carl Sassenrath"
	Rights: "Copyright 2000-2005 REBOL Technologies. All rights reserved."
	License: {
		Users can freely modify and publish this code under the condition that it is
		executed only with languages from REBOL Technologies, and user must include this
		header as is. All changes may be freely included by other users in their software
		(even commercial uses) as long as they abide by these conditions.
	}
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

system/view/vid/vid-feel: context [

	; state: for buttons that act on UP
	; data: user state for button

	sensor: make face/feel [
		cue: blink: none
		engage: func [face action event][
			switch action [
				time [if not face/state [face/blinker: not face/blinker]]
				down [face/state: on]
				alt-down [face/state: on]
				up   [if face/state [do-face face face/text] face/state: off]
				alt-up [if face/state [do-face-alt face face/text] face/state: off]
				over [face/state: on]
				away [face/state: off]
			]
			cue face action
			show face
		]
	]

	hot: make sensor [
		over: func [face action event][
			if all [face/font face/font/colors][
				face/font/color: pick face/font/colors not action
				show face
				face/font/color: first face/font/colors
			]
		]
;       cue: func [face action][
;           if all [face/font face/font/colors][face/font/color: pick face/font/colors not face/state]
;       ]
	]

	hot-area: make hot [
		over: func [face action event][
			if face/colors [
				face/color: pick face/colors not action
				show face
				face/color: first face/colors
			]
		]
		cue: none
	]

	reset-related-faces: func [face][
		if face/related [
			foreach item face/parent-face/pane [
				if all [
					item/related
					item/related = face/related
					item/data
				][
					item/data: false
					show item
				]
			]
		]
	]

	check: make sensor [
		over: none
		redraw: func [face act pos] [
			remove find face/effect 'cross
			if face/data [insert face/effect 'cross]
			if face/colors [face/color: pick face/colors not face/data]
			if face/effects [face/effect: pick face/effects not face/data]
		]
		engage: func [face action event][
			if action = 'down [
				reset-related-faces face
				do-face face face/data: not face/data
				show face
			]
		]
	]

	check-radio: make face/feel [
		redraw: func [face act pos][
			act: pick face/images (to integer! face/data) + either face/hover [5][
				1 + (2 * to integer! face/state)
			]
			either face/pane [face/pane/image: act][face/image: act]
		]
		over: func [face over offset][
			face/hover: over
			show face
			face/hover: off
		]
		engage: func [face action event][
			switch action [
				down [face/state: on]
				alt-down [face/state: on]
				up [
					if face/state [
						face/state: off
						reset-related-faces face
						do-face face face/data: not face/data
					]
				]
				alt-up [if face/state [do-face-alt face face/text] face/state: off]
				over [face/state: on]
				away [face/state: off]
			]
			;cue face action
			show face
		]
	]

	led: make sensor [
		over: none
		redraw: func [face act pos][face/color: either face/data [face/colors/1][face/colors/2]]
		engage: func [face action event][
			if any [action = 'time all [action = 'down get in face 'action]][do-face face face/data: not face/data]
			show face
		]
	]

	button: make hot [
		redraw: func [face act pos /local state] [
			if all [face/texts face/texts/2] [
				face/text: either face/state [face/texts/2][face/texts/1]
			]
			either face/images [
				face/image: either face/state [face/images/2][face/images/1]
				if all [face/colors face/effect find face/effect 'colorize][
					change next find face/effect 'colorize pick face/colors not face/state
				]
			][
				if face/edge [face/edge/effect: pick [ibevel bevel] face/state]
				state: either not face/state [face/blinker][true]
				if face/colors [face/color: pick face/colors not state]
				if face/effects [face/effect: pick face/effects not state]
			]
		]
		cue: none
	]

	btn: make button [
		over: func [face act evt][
			remove/part find face/effect 'mix 2
			if act [
				evt: any [find face/effect 'extend tail face/effect]
				insert evt reduce ['mix face/images/3]
			]
			show face
		]
		engage: func [face action event][
			remove/part find face/effect 'mix 2
			switch action [
				down [face/state: on]
				alt-down [face/state: on]
				up   [if face/state [do-face face face/text] face/state: off]
				alt-up [if face/state [do-face-alt face face/text] face/state: off]
				over [face/state: on]
				away [face/state: off]
			]
			cue face action
			show face
		]
	]

	icon: make hot [
		redraw: func [face act pos /local state] [
			if face/pane/edge [face/pane/edge/effect: pick [ibevel bevel] face/state]
		]
		cue: none
	]

	subicon: make hot [
		over: func [f a e] [f/parent-face/feel/over f/parent-face a e]
		engage: func [f a e] [f/parent-face/feel/engage f/parent-face a e]
		redraw: func [f a c] [f/parent-face/feel/redraw f/parent-face a c]
	]

	toggle: make button [
		engage: func [face action event][
			if find [down alt-down] action [
				if face/related [
					foreach item face/parent-face/pane [
						if all [flag-face? item toggle item/related item/related = face/related item/data][item/data: item/state: false show item]
					]
				]
				face/data: face/state: not face/state
				either action = 'down [do-face face face/data][do-face-alt face face/data]
				show face
			]
		]
	]

	tog: make btn [
		engage: get in toggle 'engage
	]

	rotary: make hot [
		redraw: func [face act pos] [
			face/text: face/data/1
			if face/edge [face/edge/effect: pick [ibezel bezel] face/state]
			if face/colors [face/color: any [pick face/colors index? face/data face/color]]
			if face/effects [face/effect: pick face/effects not face/state]
		]
		next-face: func [face] [
			face/data: either tail? next face/data [head face/data][next face/data]
		]
		back-face: func [face] [
			face/data: either head? face/data [back tail face/data][back face/data]
		]
		engage: func [face action event][
			switch action [
				down over [if not face/state [next-face face] face/state: on]
				up alt-up [if face/state [do-face face face/data/1] face/state: off]
				alt-down [if not face/state [back-face face] face/state: on]
				away [if face/state [back-face face] face/state: off]
			]
			show face
		]
	]

	choice: make hot [
		engage: func [face action event][
			if action = 'down [
				choose/style/window face/texts func [face parent][
					parent/data: find parent/texts face/text
					do-face parent parent/text: face/text
				] face face/parent-face
			]
			show face
		]
	]

	choice-iterator: make face/feel [
		over: func [face state] [
			face/selected: all [face/selectable state]
			show face
		]
		engage: func [face act event] [
			if event/type = 'down [
				all [face/selected face/selectable do-face face face/pane-parent]
				hide-popup
			]
			show face
		]
	]

;-- New slider and scroller code:

	drag-off: func [bar drag val /local bmax ax][
		val: val - bar/clip
		bmax: bar/size - drag/size - (2 * bar/edge/size) - (2 * bar/clip)
		val: max 0x0 min val bmax
		ax: bar/axis
		drag/offset: val/:ax + bar/clip/:ax * 0x1
		if ax = 'x [drag/offset: reverse drag/offset]
		if positive? bmax/:ax [bar/data: val/:ax / bmax/:ax]
		do-face bar none
	]

	drag: make face/feel [
		engage: func [face action event][
			if find [over away] action [
				drag-off face/parent-face face face/offset + event/offset - face/data
				show face
			]
			if find [down alt-down] action [face/data: event/offset]
		]
	]
	
	slide: make face/feel [
		redraw: func [face act pos][
			face/data: max 0 min 1 face/data
			if face/data <> face/state [
				pos: face/size - face/pane/1/size - (2 * face/edge/size) - (2 * face/clip)
				either face/size/x > face/size/y [face/pane/1/offset/x: face/data * pos/x + face/clip/x][
					face/pane/1/offset/y: face/data * pos/y + face/clip/y]
				face/state: face/data
				; RAMBO #3407
				if act = 'draw [show face/pane/1]
			]
		]
		engage: func [face action event][
			if action = 'down [
				drag-off face face/pane/1 event/offset - (face/pane/1/size / 2)
				show face
			]
		]
	]
	
	set 'scroll-drag func [
		"Move the scroller drag bar"
		face    "the scroller to modify"
		/back   "move backward"
		/page   "move each time by one page"
	][
		any [
			all [back page move-drag face/pane/2 face/page]
			all [back move-drag face/pane/2 face/step]
			all [page move-drag face/pane/3 face/page]
			move-drag face/pane/3 face/step
		]
	]
	
	move-drag: func [face val][
		face/parent-face/data: min 1 max 0 face/parent-face/data + (face/dir * val)
		do-face face/parent-face none
		show face/parent-face
	]
					
	scroll: make slide [
		engage: func [f act evt /local tmp][
			if act = 'down [
				tmp: f/axis
				do-face pick reduce [f/pane/3 f/pane/2] evt/offset/:tmp > f/pane/1/offset/:tmp f/page
			]
		]
	]
	
	scroll-button: make button [
		set-col: func [f v /local p][all [f/colors f/effect p: find f/effect 'arrow change next p f/colors/:v]]
		engage: func [f act evt][
			switch act [
				down [f/state: on set-col f 1 do-face f f/parent-face/step f/rate: 4]
				up [f/state: flag: no f/rate: none set-col f 2]
				time [either flag [either f/rate <> f/parent-face/speed [f/rate: f/parent-face/speed][do-face f f/parent-face/step]][flag: on exit]]
				over [f/state: on set-col f 1 if flag [f/rate: f/parent-face/speed]]
				away [f/state: no f/rate: none set-col f 2]
			]
			cue f act
			show f
		]
		flag: no
	]

;-------

	progress: make face/feel [
		redraw: func [face act pos][
			face/data: max 0 min 1 face/data
			if face/data <> face/state [
				either face/size/x > face/size/y [
					face/pane/size/x: max 1 face/data * face/size/x
				][
					face/pane/size/y: max 1 face/data * face/size/y
					face/pane/offset: face/size - face/pane/size
				]
				face/state: face/data
				; RAMBO #3407
				if act = 'draw [show face/pane]
			]
		]
	]

	dropdown: make face/feel [
		over: redraw: detect: none 
		engage: func [face action event][
			switch action [
				down [face/state: on]
				up [if face/state [face/show-dropdown] face/state: off]
				over [face/state: on]
				away [face/state: off]
			]
			show face
		]
	]

]

;-- Standard Accessor Functions

set-face: func [
	"Sets the primary value of a face. Returns face object (for show)."
	face
	value
	/no-show "Do not show change yet"
	/local access
][
	if all [
		access: get in face 'access
		in access 'set-face*
	][
		access/set-face* face value
	]
	if not no-show [show face]
	face
]

get-face: func [
	"Returns the primary value of a face."
	face
	/local access
][
	if all [
		access: get in face 'access
		in access 'get-face*
	][
		access/get-face* face
	]
]

clear-face: func [
	"Clears the primary value of a face."
	face
	/no-show "Do not show change yet"
	/local access
][
	if all [
		access: get in face 'access
		in access 'clear-face*
	][
		access/clear-face* face
	]
	if not no-show [show face]
	face
]

reset-face: func [
	"Resets the primary value of a face."
	face
	/no-show "Do not show change yet"
	/local access
][
	if all [
		access: get in face 'access
		in access 'reset-face*
	][
		access/reset-face* face
	]
	if not no-show [show face]
	face
]

scroll-face: func [
	"Scroll a face. Default is vertical."
	face
	offset [number!]
	/x "Scroll in width direction"
	/y "Scroll in height direction"
	/no-show "Do not show change yet"
	/local access
][
	if all [
		access: get in face 'access
		in access 'scroll-face*
	][
		access/scroll-face* face offset x y
	]
	if not no-show [show face]
	face
]

resize-face: func [
	"Resize a face."
	face
	size [number! pair!]
	/x "Resize only width"
	/y "Resize only heigth"
	/no-show "Do not show change yet"
	/local access
][
	if all [
		access: get in face 'access
		in access 'resize-face*
	][
		access/resize-face* face size x y
	]
	if not no-show [show face]
	face
]

;-- Default Accessors:

ctx-access: context [

	data: context [ ; Default accessor
		set-face*: func [face value][face/data: value]
		get-face*: func [face][face/data]
		clear-face*:
		reset-face*: func [face][face/data: false]
	]

	data-state: context [ ; e.g. toggle
		set-face*: func [face value][face/data: face/state: value]
		get-face*: func [face][face/data]
		clear-face*:
		reset-face*: func [face][face/data: face/state: false]
	]

	data-number: make data [ ; e.g. slider
		set-face*: func [face value][
			if not number? value [
				make error! reform [face/style "must be set to a number"]
			]
			face/data: value
		]
		clear-face*:
		reset-face*: func [face][face/data: 0]
	]

	data-find: context [
		set-face*: func [face value][
			all [series? face/data value: find head face/data value face/data: value]
		]
		get-face*: func [face][all [series? face/data face/data/1]]
		clear-face*:
		reset-face*: func [face][all [series? face/data face/data: head face/data]]
	]

	data-pick: context [
		set-face*: func [face value][
			all [in face 'picked insert clear head face/picked value]
		]
		get-face*: func [face][get in face 'picked]
		clear-face*:
		reset-face*: func [face][all [in face 'picked clear face/picked]]
	]

	text: context [
		set-face*: func [face value][
			face/text: value
			face/line-list: none
		]
		get-face*: func [face][face/text]
		clear-face*: func [face][
			if face/para [face/para/scroll: 0x0]
			if string? face/text [clear face/text]
			face/line-list: none
		]
		reset-face*: func [face][
			if face/para [face/para/scroll: 0x0]
			face/text: copy ""
			face/line-list: none
		]
	]

	field: make text [
		set-face*: func [face value][
			if face/para [face/para/scroll: 0x0]
			face/text: form value ; conversion/copy
			face/line-list: none
		]
		clear-face*: func [face][
			if face/para [face/para/scroll: 0x0]
			if string? face/text [clear face/text]
			; RAMBO #3445
			if flag-face? face 'hide [clear face/data]
			face/line-list: none
		] 
	]

	image: context [
		set-face*: func [face value][
			if any [image? value none? value][
				face/image: value
			]
		]
		get-face*: func [face][face/image]
		clear-face*: func [face][face/image: none]
	]

	panel: context [
		; Panel SET and GET functions only work on sub-faces flagged as INPUT
		; (keep in mind this may be panel recursive)
		set-find-var: func [pane var value][
			; Find input face with given VAR name and set it.
			foreach f pane [
				if all [
					find f/flags 'input
					f/var = var
					set-face f value
				][return true]
			]
			false
		]
		set-face*: func [face value /local val][
			; Value is a block of [val val val ...] or [name: val name: val ...]
			; If former is given, order of faces in pane must match the value block.
			; Note that the block value will be reduced before being used.
			; Only INPUT faces are set.
			if all [block? face/pane block? value][
				value: reduce value ; keeps it easy for novice users
				foreach f face/pane [
					if any [find f/flags 'input find f/flags 'panel] [
						if not empty? value [
							val: value/1
							either word? val [ ; var: value
								val: to-word val
								either f/var = val [set-face f value/2][
									if not set-find-var face/pane val value/2 [
										set-face/no-show f value/2 ; must be a synth name
									]
								]
								value: skip value 2
							][ ; no var given, so just set next value
								set-face f val
								value: next value
							]
						]
					]
				]
			]
		]
		get-face*: func [face /local blk synth var][
			; Returns a block of [var: value var: value ...] for all INPUT faces.
			if block? face/pane [
				synth: copy [] ; list of [style count style count ...]
				blk: make block! 6 ; ok starting guess
				foreach f face/pane [
					if any [find f/flags 'input find f/flags 'panel] [
						if not word? var: f/var [ ; need to synth a var
							either var: find synth f/style [
								change next var n: var/2 + 1
							][
								repend synth [f/style n: 1]
							]
							var: to-word rejoin [f/style #"-" n]
						]
						repend blk [to-set-word var get-face f]
					]
				]
			]
			blk
		]
		clear-face*: func [face][
			if block? face/pane [
				foreach f face/pane [
					if any [find f/flags 'input find f/flags 'panel] [
						clear-face/no-show f
					]
				]
			]
		]
		reset-face*: func [face][
			if block? face/pane [
				foreach f face/pane [
					if any [find f/flags 'input find f/flags 'panel] [
						reset-face/no-show f
					]
				]
			]
		]
	]

	system/view/vid/vid-face/access: data ; default accessors
]

;do %/c/build/simple-tests/access.r