REBOL [
	Title:  "REBOL/View: Built-In Images"
	Author: "Carl Sassenrath"
	Rights: "Copyright 2000 REBOL Technologies. All rights reserved."
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

load-stock: func [
	"Load and return stock image. (Keep cache after first load)"
	name
	/block size ; return block of consecutive images
	/local image
][
	if not image: find system/view/vid/image-stock name [
		make error! reform ["Image not in stock:" name]
	]
	either block [
		block: copy []
		loop size [
			if not image? second image [change next image load second image]
			append block second image
			image: skip image 3
		]
		return block
	][
		if not image? second image [change next image load second image]
		return second image
	]
]

load-stock-block: func [
	"Load a block of stock image names. Return block of images."
	block /local list
][
	list: copy []
	foreach name block [append list load-stock name]
	list
]

system/view/vid/image-stock: [

logo 64#{
R0lGODlhZAAYANQdAAICAoWFhcPDw0RERCUlJaWlpePj42NjYxQUFJSUlNTU1DQ0
NLW1tfX19XNzc1JSUgsLC4yMjMvLy0tLSy0tLaurq+zs7GxsbBwcHJubm93d3T09
Pb29vf7+/nx8fFpaWiwAAAAAZAAYAAAF/yCBjGRpnmiqrifmWF0sx9LE3ogI7Hzv
/8CgcOjbCGZIWQFBJEKYzah02nvAklgJgeobcb/gKnYcU0C/3rB6SriSsZVwmrcZ
2O8bjHBx7w8oPxAbg4QbgEEVWAYcFQwKYx8+gnaHQHMAEBpYDRlBHGNxPgQNWAJ6
RUkaBxA8ghJJEqKkHZ1Bl5lkAUBHWAw/BGQcrD0ZSBynksVIEz3AMbWWZ5iaHTUT
DrMKQJ8dFhcH4AcDv7MJAxPcHVs8GG4dBsi7SL48o89Ct9T0AI8dGsM9uGloYq/D
gR0eYjSINwCJhx4YJlQC8ACJhTMFof3IF0MABQoeZu0LqLBAhpMFLv+Qi8HAQQAY
DR72+IBkQz1NFsbtgGAASaWM+KThwmJhwbYxI3cURCJAGoALMxbySEijB4Oa9WZp
7CKUmjGjR2MYGDs2wcp3EhRkW7cDqgypOyLIMAAw0QybSrUG7TFUwARqBpiFNYAA
gmGAzWY52NEwhswdB3zymCBDF49+MsACAGqrK0sAjd/F4yGQ4KyDACjI0Eh5Buod
DwK8BrAASQOMejvz1beDVwfLPrhZ8ODAg/EHZwUkyOD18WYkEhD/KAA9cQwNBSpU
KDCRYwcOjGVYGA3A97xfZBSw3ZEuhtkgDpKorDdG5w7v+67GiPCj/YxQzRhgwYAD
GiBABE4BQNN2PJrdp8wMhDVTXw+XAFDHH/Xc0eAOC0zg4YcebnifCdLxhdlbAmQQ
QQIM9JQEcDtN8MCMND4gTYVr5AhEa29gYQYYOOooJA9y9WibfVwEOeSQCRj5FnJy
JLjkkiEZqQGUYUAgAg5cdunlCAPoR1QCW35ZAgEhAAAh/h9PcHRpbWl6ZWQgYnkg
VWxlYWQgU21hcnRTYXZlciEAADs=
} 0

icon-image 64#{
R0lGODlhMAAwAOUhAAICAneCkT1IT2BhYiYsLLy8uVBbZGJpfoWNo0FCQi04OxgZ
G01PUaenpml2g2JyelJcal9ldJCcsa6aeujo5SEiInN8kS8yNIqKiUVPVzZARWts
b0xVYFpmchMTE4yVr2FreP7+/MzMyJ+pv5iYlrKyrvLy6nJycoKLnnuGmTtGSQ4O
DsbGxJmguENJUyoxNVddZGZoaSMlKgoLC8XFvomTpzM6QFVVVW95idbS0nx8ekdH
RWdwgDtASBofIFdgbCwAAAAAMAAwAAAG/8CJcEgsGo/IpHLJbDqf0Kh0WrxZGdis
dsvteneXmXEXiw0GsLK6vIlt3ubzQA1Xy+flwQVgvNw6HCoZPCARDg44iTgBATg8
PxwcHQ8OKTUoOIcdMDAGMIYOFntGFQkqBDIqBpEGED8QEAatHAIvLxouLhwPFg6A
GS4ZkRzAHCAEfEWlNgQKNgIcq9GrBiCIPKEpKRYWKAgOPxkZP9Q/HRkGOMikCQYC
AjYqGuLiEDzaES4KCrY2LhEIRkjAIQuQABUuIP1AMUpZggcGMtjgt++CAUQGbHjY
uAIAgBkeKmjggQJFChzhNGhQEalDjYZESpnjcKHCC2fpDLzw4LGnT/+PHmxkcPDB
QqAe0IZKgDmkFIxzBC74A2EBhoyOP7N6nPGCRw0cwyLiWJosZgIeHTQ00wAiAAQf
WuP2rADQgQFIBgJ8YCqkFI4Mtl4YSPEDrtzDCxaeQxcAwYuyTRNAmGjDBlrDhw/7
oAqBAwQHKB6zyyBPAYcDNg6D9IAVwIIKrQFoSMGDww8cLyH3TRBoYgQOsX962NCg
wYkZMk40KEBiD9AOKVZ55TuhFAcNLwTgEHC4QoEQIXLo+A4+RIkKPXvUAJEBhDrd
1RMAJtABxwLNJUKYMFF+fwgKDPS0QCE2GCMDfKXsowJtmfmQH38UlECBfv/t4BMH
DiTUwYGjZQD/wQc/NJiffjrIQEJ5GPDUkwsIrJIBeuxEAAEIEqSGH3giIFNBDBgM
cJ9PMqAgQDAwOgTCAQ/UgN6NIdDw40daeWDUDz9w6FAmICDwZFwOgkfDknKtEN1d
Vpp1EkBgcjnil5ktYMFBAhRpJg4g1GDjT0922WSaWr0QXQZxIpiABQ9kGcFPFzTA
QnMA6MnmYQag8IoBZUbmQAReoeCTd+UVsMACa/Ip3AEgCIBOpbvB8ApuB3rEAHgQ
7uBBqIe98JdUgcYIjAHr9bQDrP8lMCt4LIjq0w8paHCBM3Cxwx5CerXqwYngkbDC
AuSJYKxHPmwjgALLNusQD+4IcEALFgg4/0CPPK2QwBk7BNfTDJEGAIMGE4lrViys
BCABBz7Jm5kBCNzzlwYK6BtZNObgkEILI2SQmVzqWZBOAOdsKOgDPHRc6D3JTpyV
ehJ08AMIPHD8g5yRtfXBByg0gkNAPGyJ2A8StJACCNQAygGq8aElizDCGGBwBjbj
mYFeEiCQAji6FAR0KSogpAum2GDTGAIHuPDCAjOAVIENEFhwUgoSSFCD0xac08OL
giprwzw84MBNI9jYbZIFdvPNQwSbjMPDAb6gk4EGAlQZ9zsGQGfJNg6AYHIHgKig
QA9IiXMXLUgJ8sPfDE+dAC62OVBD2gjQSXksqwiAFCsnH9CBLLJ8/kN0NBCwLIQH
F9wCzQ+84GAyMcAIw3kPLvQwzw8yZoC5Bj18/kPn9xnR6EbYZ6/99tx3z9EM8Iks
/vhUlG/++einz0QQACH+H09wdGltaXplZCBieSBVbGVhZCBTbWFydFNhdmVyIQAA
Ow==
} 0

btn-up 64#{
iVBORw0KGgoAAAANSUhEUgAAAAcAAAAOCAYAAADjXQYbAAAAE3RFWHRTb2Z0d2Fy
ZQBSRUJPTC9WaWV3j9kWeAAAAHFJREFUeJxt0KsNQCEMhWFmYgY2ZhM2QCBqEBgS
DJfT5PC8JL/pV0yNGc85Z0d9y5od9jcXCK21Wa1VFxQ5QKWUnnNeSEAAETkRPxAg
xrgQ2wwQQniRvw7EkP1iSkl7EAMGOJAD5L3XiHo+DgnPfe/Df37VC78nAOT0AAAA
AElFTkSuQmCC
} 0

btn-dn 64#{
iVBORw0KGgoAAAANSUhEUgAAAAcAAAAOCAYAAADjXQYbAAAAE3RFWHRTb2Z0d2Fy
ZQBSRUJPTC9WaWV3j9kWeAAAAE9JREFUeJxjYAACFxcXIyD+j4SNGJAlNm/eDMdw
BegSyApQJC9duvT/4cOHYIwiCZIYKEmYAqyuhWHijYUJvnz5EkUSHHwgQRjGGr7o
AQ8AhL78UJZD9twAAAAASUVORK5CYII=
} 0

btn-hover 64#{
iVBORw0KGgoAAAANSUhEUgAAAAcAAAAOCAYAAADjXQYbAAAAE3RFWHRTb2Z0d2Fy
ZQBSRUJPTC9WaWV3j9kWeAAAAFFJREFUeJxjYCAG/Ls/6z8MY0j8uVQFxygKYJIg
NmmSMOPQ2WDw63jifxBGZ4PBz33e/0EYnU1Y8scW0/8gjM4mXhIZo4TS0+kM/2EY
bzjDAAB5cpSRQutBMQAAAABJRU5ErkJggg==
} 0

;Old circular versions:
;btn-up 64#{
;iVBORw0KGgoAAAANSUhEUgAAAAwAAAAMCAYAAABWdVznAAAABGdBTUEAALGOfPtR
;kwAAACBjSFJNAAB6JQAAgIMAAPn/AACA6AAAdTAAAOpgAAA6lwAAF2+XqZnUAAAB
;S0lEQVR4nGL4//8/AykYIIBQONXV1XuKiop+RkRE/AfhkpKSX1VVVXuR1QAEEJxR
;WVn5oqen5/+RI0f+v337FoxB7N7e3v8gOZg6gAACE7W1tcdBinGB7u5ukKYTHz9+
;ZAYIILAGoLX/QKZhAz9+/Pi/bdu2/zk5Of9AagECCKwhKioK7ARsil+9evX/3Llz
;/728vEBCDAABhFXDv3///v/69Qssdvfu3f8HDhz47+LiAtYAEEBgDfX19WAP/vnz
;B2wq0K1gk2/fvv3/1KlT/ydPnvw/OjoarAEggMAaOjo67nV2dv5//fr1/ydPnoBN
;vXz58v+jR4/+37Fjx/+UlJT/WVlZD0BqAQIIHqxAW37V1NT8X7x48f+9e/f+37Rp
;Ezh0QIqB+BdMHUAAoUfcE5ACJyen//b29uDIA4bOM2Q1AAFEUrIAYYAAAwChoLYW
;+z51JwAAAABJRU5ErkJggg==
;} 0
;
;btn-dn 64#{
;iVBORw0KGgoAAAANSUhEUgAAAAwAAAAMCAYAAABWdVznAAAABGdBTUEAALGOfPtR
;kwAAACBjSFJNAAB6JQAAgIMAAPn/AACA6AAAdTAAAOpgAAA6lwAAF2+XqZnUAAAB
;fklEQVR4nGL8//8/AykAIIBYkDm5ubnP3rx5I/n8+XMGZmZmBiUlJQZxcfGnLS0t
;MjA1AAHECLMhNTX1F5BiVVdXZwBhbm5uhmfPnjHcvHkTpPl3Q0MDG0gdQACBNWRn
;Zz/49euXfEhICAMvLy8DHx8fAxcXFwM7OzsYz5s3jwGo7n55ebkSQAAxgXR9/PhR
;Xl9fn0FISIhBTEwM5AwGQUFBBn5+fgY2NjYGNzc3hu/fvyuC1AIEENgPL1++ZNDV
;1WUQFhZmEBAQYGBlZWVgYWEB0//+/WOQk5NjuH37NtjpAAEE1gAyBeQMkHMYGRnB
;fBAGsdEBQACBnQQMjf8vXrwAmwpyMyiEkBVfv36dQUFBARw6AAEE1gA0+dTVq1ch
;JjAxgTUigxMnToAMOQliAwQQPFirqqpeiIiIiJubmzNoamrCTQYpfvv27UtgCNoZ
;GRndAgggRuSYrq6u3gsMXtsnT56wgvhSUlK/ODk5DwMjzgWmBiCAGElNGgABBgBz
;mnKuLtYBTAAAAABJRU5ErkJggg==
;} 0
;
;btn-hover 64#{
;iVBORw0KGgoAAAANSUhEUgAAAAwAAAAMCAYAAABWdVznAAAABGdBTUEAALGOfPtR
;kwAAACBjSFJNAAB6JQAAgIMAAPn/AACA6AAAdTAAAOpgAAA6lwAAF2+XqZnUAAAB
;aklEQVR4nGL8//8/AykAIICYSFINBAABxAJjTJw4kUGC55SVq+WhTCHed6Ygsbef
;RQ7sOeUw/8VHo5P5+flgdQABxAByEgivmBNl9f8xz81vt4X//7rD9//3Pb7/34Hs
;/4+4T6yYH2MJUwcQQIwwP7y9LH+Hnf2v8qXbyucu39etAYnpKl5u1le5bvztF8c8
;Ud1HySAxgACC2/D/IeePb7cE/8+YnO0FEwOxX18U/v/5KucFmBhAAMH98OXrP4bn
;rzHD4OfPfww/fzC+5YHyAQIIruHzD7HX//8zymjLX+maOSWHAeqk3l//OBj+/OO8
;CVMHEEBwDUcu2URbaWyplmP/4yYjdGnr919MDP+Y2BlY/n/Zefy63yJVS4g6gACC
;a3j2wfzQwSsMf3QV97/jZv8lxs7GwPDtJ/uNozd8lrz+bHoCpg4ggOAaQOD1F/Nj
;+y6bH3v//j3YM4KCgv/Q/QQQQIykJg2AAAMAV9GsqOWrN8wAAAAASUVORK5CYII=
;} 0

exclamation 64#{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} 0

help 64#{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} 0

info 64#{
R0lGODlhMAAwAIcuAKKns7a3uqywvIeRq3J8mbO0uLS3wqGovYWPqV1qjVBdgrGz
tra5w6mww5egtnmEoVRihzlJc0lWd7GytpujuYONqGZylEpZgDlIcjVDakhUdKqx
w2dzlFBehEFQejZFbjRDamh1lVFfhUNTezxMdzlJdDhIcjtLdjpKdWdzk2VwkGRv
jU1ZfTdHcP///4+Tnio2VTZFbYeJjhcdLjE/Yw8THS88Xyo1VBkgMzJAZEtXekVO
Zz9HXD9GXC85Uy47XTdGb7W4w+Tm63N5iTRCaUdTcrGytbO3waivwuPk6Wdpbxwk
OThHcTA+YkNNarCxtKquu56mu5WetYKMp+Lk6BQaKTJAZThHcDNBZyw5WSYxTTtD
WbCxs6istYCLpn6IpXWAnmRwki05WyMtSBwkOBkgMltgbIePoldkiUhXfz9PeS06
XCMsRhgfMRIWIzg7Rba2t3N8lBceLzc6Qra2tnB4jjZEbG93jDRCaCw4WR4mPDNC
aDVEays3VyUvSyQuSSgzUDA9YTZEbTdHbzJAZhgeMG93izA+YSQuSBkfMg8THm1z
hycyTx0lOxIYJWhufRsjNzk9SHp9h7a3t////wAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAACH5BAEAAJQALAAAAAAwADAAAAj/ACkJHEiwoMGDCBMqXFgQ
QACGECMaFDCAQAGJGBkaOIAggYIJGUMaZLDBwQMIESSAFCmSJIUKFi5EyKCSZUaX
MEWMiPCB5kqbDHGG0EkCBU+fQBcKJYqi6dGaSQ8uHVG0qdOeUKMOnFrV6lWkWilx
9Ur26U+gY8mWxXq25YaXQ6mqnWvWZtqmKVKsWMGixVqwN99WiNu1qYvDLl7A+PA3
a8S7VhG7kDGDhtq6jwUTnitZhiIbdNlChOwVhqLTispgmWtUtELSXnXs6NHDxw/G
rDFL1cyUNQohiIf88Ov7aJG2Ao8ggdvbN/DDShpl8N0UQwYaTtpCiSJlioXmzhEr
/6mymjoGLGK0bOEysMsUL2BSgA8Pnbz5DGL+NCpjhuAZNCKkoUZh1D3nwnjlzWXd
D2wk4sYbdBQUBwYYRBABdV4ZiCBrC7IxgyJzRGhQHRl8UCGGTWlon1odfhhiQneU
eCKGKiZoVYsgigijjBcWKN6KN2bAoIs6KhSjiT2yVqNXOL4Y0ZEzzrVkdUJ6mGNG
UCZJ1pRNFilRllL+uFqXNoFJlhioKaIHCGQCZaZVfMDghx+A0NDTkFdG9SaLVRIZ
FiV7Bomnk38G2uafAr15KKKJ8ojCoow2+sGkfeYZaUF3YJEBeg1aemlBhtAghh+J
ePppQYto0YgjhJ560COQRA3ipasGSTIrrbjmWlBAACH+H09wdGltaXplZCBieSBV
bGVhZCBTbWFydFNhdmVyIQAAOw==
} 0

stop 64#{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} 0

check 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
FHRFWHRBdXRob3IAcm9zcy1naWxsLmNvbf6SRqsAAAA3SURBVHjaTc65EQAwCANB
CqABg91/m4xkvss2O9Gd6GFm7rdElD5SiUcVqAY0oBrQgGpAA2h/BlFFDzHRV5dq
AAAAAElFTkSuQmCC
} 0 

check-on 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
FHRFWHRBdXRob3IAcm9zcy1naWxsLmNvbf6SRqsAAABCSURBVHjaTc7BDQAgDAJA
vyQuYKX7r6mlVuV3CSG0/qf1oZjNyZJQCqAkgC5BgEsGJEK2lZBOLRXTCYmkXz2E
/p8LyQ8NqaRJSfoAAAAASUVORK5CYII=
} 0 

check-down 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
FHRFWHRBdXRob3IAcm9zcy1naWxsLmNvbf6SRqsAAAA7SURBVHjaTc6xDQAwCANB
BqANAvYfNLIJhO+usSy6Ez2VmfsIGBGtQpSIiFKDaiQ0yIQGENeIp/jaPy+mIA1e
lWREdgAAAABJRU5ErkJggg==
} 0 

check-down-on 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
FHRFWHRBdXRob3IAcm9zcy1naWxsLmNvbf6SRqsAAABDSURBVHjaTc4xDgAgCANA
xw6uEuD/D5WCot0uaZqO+WfMVRFRbRGtAFoE1FJIwI5QSAmQcOrW3J2K6QIV0MKR
Pf0/NzMuDBIfO4TgAAAAAElFTkSuQmCC
} 0 

check-hover 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
FHRFWHRBdXRob3IAcm9zcy1naWxsLmNvbf6SRqsAAABRSURBVHjaTc5bCgAhCAXQ
0Kv9tIFq3P82x0czdBHhoKBt3Gmjd/WIF0IH3nI251p7P58SJe2FXwlTpAoGDmnB
OCRSMCYXEMfAfAQRB1Fs3n++ODQI8bWz6M4AAAAASUVORK5CYII=
} 0 

check-hover-on 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
FHRFWHRBdXRob3IAcm9zcy1naWxsLmNvbf6SRqsAAABVSURBVHjaTc4JCsAwCATA
EI8g5AM5/P8369q0REQYVtDS7yq9NY2SaIYOYmQ2xpxr2afEK22W+GWAKx8BzgRp
Ju4EiewNONUQM44x0RGLBGrF5v3nA6/+B2n+wZJbAAAAAElFTkSuQmCC
} 0 

radio 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
AXRSTlMAQObYZgAAABR0RVh0QXV0aG9yAHJvc3MtZ2lsbC5jb23+kkarAAAAQ0lE
QVR42l3OMQ4AIAhDUfa/dFXx/tdUCSTEbi9NoGYvgFVAUhmNMecSDcuDJNyJKrFv
iQqpxJNR2HFFiXrR8G1pOw+IpAoH/3HUSAAAAABJRU5ErkJggg==
} 0 

radio-on 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
AXRSTlMAQObYZgAAABR0RVh0QXV0aG9yAHJvc3MtZ2lsbC5jb23+kkarAAAAVElE
QVR42l3OwQ7AIAgDUI5KL72K8P+/uepmYsaJlyYFszUA7AxA8hgcI2ISF2ZuQnD3
zMSOhN5blkIwQuitPs0VvTKooC3UbqEKtNc5ceH3y/XnA/+XCIHUfbDCAAAAAElF
TkSuQmCC
} 0 

radio-down 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
AXRSTlMAQObYZgAAABR0RVh0QXV0aG9yAHJvc3MtZ2lsbC5jb23+kkarAAAARklE
QVR42l3OwQoAIAgDUO+D3Qzr/z+0MkfRbg9RZ7YDwBSApAy6e2vEg4gkChE4o0Tv
a7hUOBLGXoQw8goLehEXX5en5wQYOAjRqD4UZwAAAABJRU5ErkJggg==
} 0 

radio-down-on 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
AXRSTlMAQObYZgAAABR0RVh0QXV0aG9yAHJvc3MtZ2lsbC5jb23+kkarAAAAVElE
QVR42l3OSw7AIAgEUJfIJOwkg/c/aEFjazq7lwmf1ioA2glgZsewMYa74QK5iISq
ksSuVHuXiCxTnnjlJZGYNYhcIIW5thgZkTgn+OH3y/XnA6vXB5sQqqAAAAAAAElF
TkSuQmCC
} 0 

radio-hover 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
AXRSTlMAQObYZgAAABR0RVh0QXV0aG9yAHJvc3MtZ2lsbC5jb23+kkarAAAAXUlE
QVR42lXOMQ4AIQhEUZMBLKYisXL1/tdcwLVYKl5+orSWQ7LdIX34NX126+a8wIRo
kbvP+TxLhZmiBBYkIocV1kYq2kG2RpPEBuoVV0XsuF+IQD7ULe6/287+AnsyBs+g
3sRlAAAAAElFTkSuQmCC
} 0 

radio-hover-on 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANCAMAAABFNRROAAAAYFBMVEXs6dgAAADl
lwD4tDX5vkv6x2H80nr+35omfAgAmQAiwCAAM2YcUYAAZplkh9x/nbmLqeW7mVVv
eWesqJm5tanHxbLJx7rV0MTX1Mrk4tnp6OHw8Or09PD6+vj///////8AldVgAAAA
AXRSTlMAQObYZgAAABR0RVh0QXV0aG9yAHJvc3MtZ2lsbC5jb23+kkarAAAAZElE
QVR42lWOMQ7AIAwDkQg4xFOkslSF/z+zpC1DPeV0kuOUIiTTDtmPvpn9REV1bsCE
lAc5MM3sKsJQgFlrClmSR50Lmo4cFG7B6xKrXKo6JD8tXgoGJH8vXCRviC3u/tv2
3jcP8wWPGnMh1wAAAABJRU5ErkJggg==
} 0 

arrow 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANBAMAAACAxflPAAAAMFBMVEXs6dh4n+yW
tu+lvO6sxPK2yfG7zfXF1PXQ2/X///8AAAAAAAAAAAAAAAAAAAAAAADu3bw7AAAA
AXRSTlMAQObYZgAAABR0RVh0QXV0aG9yAHJvc3MtZ2lsbC5jb23+kkarAAAAQ0lE
QVR42mNgmAkEExgYOF2AwJOBYUpHe3laygQgXV4GpoHctBAgXQ6j0yB0GZB2AdJA
KhVKh4Hp0BAXkwlw86DmAwClWyTDYcm/OAAAAABJRU5ErkJggg==
} 0 

arrow-down 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANBAMAAACAxflPAAAAMFBMVEXs6dh4n+yW
tu+lvO6sxPK2yfG7zfXF1PXQ2/X///8AAAAAAAAAAAAAAAAAAAAAAADu3bw7AAAA
AXRSTlMAQObYZgAAABR0RVh0QXV0aG9yAHJvc3MtZ2lsbC5jb23+kkarAAAAPElE
QVR42mNgmAkEExgYOAWBQJKBYWKQkpKSxwSGiaqhLi4WIDoESrtAaBUCtLOxsTGQ
5uwAgk4GBqj5AKFLHXrDae6sAAAAAElFTkSuQmCC
} 0 

arrow-dark 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANBAMAAACAxflPAAAAMFBMVEXs6dgzRGYz
VXc8XoJEZo5Nb5lVd6RegLBmiLv///8AAAAAAAAAAAAAAAAAAAAAAAA8YKRmAAAA
AXRSTlMAQObYZgAAABR0RVh0QXV0aG9yAHJvc3MtZ2lsbC5jb23+kkarAAAAQ0lE
QVR42mNgmAkEExgYOF2AwJOBYUpHe3laygQgXV4GpoHctBAgXQ6j0yB0GZB2AdJA
KhVKh4Hp0BAXkwlw86DmAwClWyTDYcm/OAAAAABJRU5ErkJggg==
} 0 

arrow-dark-down 64#{
iVBORw0KGgoAAAANSUhEUgAAAA0AAAANBAMAAACAxflPAAAAMFBMVEXs6dgzRGYz
VXc8XoJEZo5Nb5lVd6RegLBmiLv///8AAAAAAAAAAAAAAAAAAAAAAAA8YKRmAAAA
AXRSTlMAQObYZgAAABR0RVh0QXV0aG9yAHJvc3MtZ2lsbC5jb23+kkarAAAAPElE
QVR42mNgmAkEExgYOAWBQJKBYWKQkpKSxwSGiaqhLi4WIDoESrtAaBUCtLOxsTGQ
5uwAgk4GBqj5AKFLHXrDae6sAAAAAElFTkSuQmCC
} 0 

]

foreach [name data flags] system/view/vid/image-stock [
	if not all [word? name binary? data integer? flags][
		print "Invalid image-stock"
		wait 3 quit
	]
]

;-- Legacy image variables:
logo.gif: load-stock 'logo
system/view/vid/radio.bmp: load-stock 'radio
system/view/vid/radio-on.bmp: load-stock 'radio-on
system/view/vid/icon-image: load-stock 'icon-image
btn-up.png: load-stock 'btn-up
btn-dn.png: load-stock 'btn-dn
exclamation.gif: load-stock 'exclamation
help.gif: load-stock 'help
info.gif: load-stock 'info
stop.gif: load-stock 'stop
