REBOL [
	Title:  "REBOL/View: Object and Core Functions"
	Rights: "Copyright 2000 REBOL Technologies. All rights reserved."
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

system/view: make object! [

	screen-face: make face [
		pane: []
		feel: make feel [
			event-funcs: []
			detect: func [face event][
		;		if not object? face [print "detect got no face"]
				foreach evt-func event-funcs [
					; The evt-func function returns tristate:
					;	1. event: not my event, try next handler function
					;	2. true: my event, but return event from detect
					;	3. none: my event, return none
					if not event? evt-func: evt-func face event [
						return either evt-func [event][none]
					]
				]
				event
			]
			;-- protect 'detect  !!!CES
		]
	]
	focal-face:
	caret:
	highlight-start:
	highlight-end: 
	title-size:
	resize-border:
	no-resize-border:
		none
	line-info: make object! [
		start:				; series reference to start of line
		num-chars:			; count of number of chars in line
		offset:				; xy position of line
		size: none			; width and height of line
	]
	VID: none

	;-- end of C struct

	event-port: none
	debug: none
	pop-face: none
	pop-list: []

	set 'show-popup func [face [object!] /window window-face [object!] /away /local no-btn feelname] [
		if find pop-list face [exit]
		window: either window [feelname: copy "popface-feel-win" window-face][
			feelname: copy "popface-feel"
			if none? face/options [face/options: copy []]
			if not find face/options 'parent [
				repend face/options ['parent none]
			]
			system/view/screen-face
		]
		; do not overwrite if user has provided custom feel
		if any [face/feel = system/words/face/feel face/feel = window-feel] [
			no-btn: false
			if block? get in face 'pane [
				no-btn: foreach item face/pane [if get in item 'action [break/return false] true]
			]
			if away [append feelname "-away"]
			if no-btn [append feelname "-nobtn"]
			face/feel: get bind to word! feelname 'popface-feel
		]
		insert tail pop-list pop-face: face
		append window/pane face
		show window
	]

	set 'hide-popup func [/timeout /local win-face] [
		if not find pop-list pop-face [exit]
		win-face: any [pop-face/parent-face system/view/screen-face]
		remove find win-face/pane pop-face
		remove back tail pop-list
		if timeout [pop-face: pick pop-list length? pop-list]
		show win-face
	]

	wake-event: func [port /local event no-btn][
		event: pick port 1
		if none? event [	; this is bogus - why no event data
			if debug [print "Event port awoke, but no event was present."]
			return false
		]
		;print event/type
		either pop-face [
			; there is a modal window up
			; handling the current pop-face
			if in pop-face/feel 'pop-detect [event: pop-face/feel/pop-detect pop-face event]
			do event
			found? all [
				pop-face <> pick pop-list length? pop-list
				; pop-face has been closed
				(pop-face: pick pop-list length? pop-list true)
			]
		] [
			do event
			empty? screen-face/pane
		]
		;returns either value
	]

	set 'do-events func [
		"Process all View events."
	][
		wait [] ; should be none!!!
	]

	set 'open-events does [
		if event-port [exit]
		event-port: open [scheme: 'event target: "events"]
		event-port/awake: func [port] [wake-event port]
		insert system/ports/wait-list event-port
	]

	window-feel: make face/feel [
		detect: func [face event][
			; Detect if a key has been pressed, and whether this window
			; has any shortcuts for it.  The system would work better if
			; we knew in advance if a window had a shortcut key and this
			; function could be nulled out.
			either all [
				event/type = 'key
				face: find-key-face face event/key
			][
				if get in face 'action [do-face face event/key]
				none
			][
				event
			]
		]
	]

;------- Popup windows feels

	; normal popup feel
	popface-feel: make window-feel [
		close-events: [close]
		inside?: func [face event] [face = event/face]
		; ingore outside events
		process-outside-event: func [event] [
			either event/type = 'resize [event] [none]
		]
		; detects ALL events, for all faces
		pop-detect: func [face event] [
			either inside? face event [
				either find close-events event/type [hide-popup none] [event]
			] [
				; event is ouside the popup
				process-outside-event event
			]
		]
	]

	; popup feel for a popup without buttons
	popface-feel-nobtn: make popface-feel [
		append close-events 'up
	]

	; popup feel for /away popup
	popface-feel-away: make popface-feel [
		process-outside-event: func [event] [
			; event is ouside the popup, close the popup
			; fix: don't close on active/inactive
			unless find [move time active inactive] event/type [hide-popup]
			event
		]
	]

	; popup feel for /away popup without buttons
	popface-feel-away-nobtn: make popface-feel-away [
		append close-events 'up
	]

	; popup feel for a popup inside another window
	popface-feel-win: make popface-feel [
		close-events: []
		inside?: func [face event] [within? event/offset win-offset? face face/size]
	]

	; popup feel for a popup without buttons inside another window
	popface-feel-win-nobtn: make popface-feel-win [
		append close-events 'up
	]

	; popup feel for /away popup inside another window
	popface-feel-win-away: make popface-feel-win [
		process-outside-event: get in popface-feel-away 'process-outside-event
	]

	; popup feel for /away popup without buttons inside another window
	popface-feel-win-away-nobtn: make popface-feel-win-away [
		append close-events 'up
	]

;-------

	set 'view func [
		"Displays a window face."
		view-face [object!]
		/new "Creates a new window and returns immediately"
		/offset xy [pair!] "Offset of window on screen"
		/options opts [block! word!] "Window options [no-title no-border resize]"
		/title text [string!] "Window bar title"
		/local scr-face
	][
		scr-face: system/view/screen-face  ; reduces path overhead
		if find scr-face/pane view-face [return view-face] ; should bring to top !!!
		either any [new empty? scr-face/pane][
			view-face/text: any [
				view-face/text
				all [system/script/header system/script/title]
				copy ""
			]
			new: all [not new empty? scr-face/pane]
			append scr-face/pane view-face
		][change scr-face/pane view-face]
		; Use window-feel, not default feel, unless the user
		; has set their own feel (keep user's feel)
		if all [
			system/view/vid
			view-face/feel = system/view/vid/vid-face/feel
		][
			view-face/feel: window-feel
		]
		if offset [view-face/offset: xy]
		if options [view-face/options: opts]
		if title [view-face/text: text]
		show scr-face
	;	show view-face
		if new [do-events]
		view-face
	]

	set 'unview func [
		"Closes window views, except main view."
		/all "Close all views, including main view"
		/only face [object!] "Close a single view"
		/local pane 
	][
		pane: head system/view/screen-face/pane
		either only [remove find pane face][
			either all [clear pane][remove back tail pane]
		]
		show system/view/screen-face
	]
]

