REBOL [
	Title:  "REBOL/View: Requestors"
	Author: "Carl Sassenrath"
	Rights: "Copyright 2000 REBOL Technologies. All rights reserved."
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

req-funcs: context [

	; changed as suggested in RAMBO #3052
	set 'request func [
		"Requests an answer to a simple question."
		str [string! block! object! none!]
		/offset xy
		/ok
		/only
		/confirm
		/type icon [word!] "Valid values are: alert, help (default), info, stop"
		/timeout time
		/local lay result msg y n c width f img rtn y-key n-key
	][
		rtn: func [value][result: value hide-popup]
		icon: any [icon all [none? icon any [ok timeout] 'info] 'help]
		lay: either all [object? str in str 'type str/type = 'face] [str][
			if none? str [str: "What is your choice?"]
			set [y n c] ["Yes" "No" "Cancel"]
			if confirm [c: none]
			if ok [y: "OK" n: c: none] 
			if only [y: n: c: none]
			if block? str [
				str: reduce str
				set [str y n c] str
				foreach n [str y n c] [
					if all [found? get n not string? get n][set n form get n]
				]
			]
			width: any [all [200 >= length? str 280] to-integer (length? str) - 200 / 50 * 20 + 280]
			layout [f: text bold to-pair reduce [width 1000] str]

			img: switch/default :icon [
				info [info.gif]
				alert [exclamation.gif]
				stop [stop.gif]
			] [help.gif]

			result: copy [
				;backcolor base-color
				across
				at 0x0
				origin 15x10
				image img
				pad 0x12
				guide
				msg: text bold black copy str to-pair reduce [width -1] return
;				(either (8 + img/size/y) > pick size-text f 2 [
;						compose [pad (to-pair reduce [0 8 + img/size/y - pick size-text f 2])]
;					] []
;				)
				pad 4x12
			]
			y-key: pick "^My" found? ok       ; ENTER or Y
			n-key: pick "^[n" found? confirm  ; ESCAPE or N
			append result pick [
				[key #"o" [rtn yes] key #" " [rtn yes]]
				[key #"n" [rtn no] key #"c" [rtn none]]
			] found? ok
			if y [append result [btn-enter 60 y y-key [rtn yes]]]
			if n [append result [btn       60 silver n n-key [rtn no]]]
			if c [append result [btn-cancel 60 c escape [rtn none]]]
			layout result
		]
		result: none
		either offset [inform/offset/timeout lay xy time][inform/timeout lay time]
		result ; is set by the pop-up buttons
	]

	; The titles of these windows should have the function names e.g.: alert !!!
	set 'alert func ["Flashes an alert message to the user. Waits for a user response." str] [request/ok/type str 'alert]
	set 'notify func ["Flashes an informational message to the user. Waits for a user response." str] [request/ok/type str 'info]

	set 'confirm func [
		"Confirms a user choice." 
		question [series!] "Prompt to user"
		/with choices [string! block!] 
		/local yes no
	][
		question: form question
		if with [
			yes: "Yes"
			no: "No"
			if string? choices [yes: choices]
			if all [block? choices not empty? choices] [
				either tail? next choices [yes: choices/1][set [yes no] choices]
			]
			question: reduce [question yes no]
		]
		request/confirm question
	]

	set 'flash func [
		"Flashes a message to the user and continues."
		val
		/with face "Center over this face"
		/offset xy
	][
		val: layout [
			origin 10x10
			image info.gif
			origin 62x24
			text bold form val 200x-1
			origin 20x20
		]
		val/text: "Information"
		either offset [val/offset: xy][
			center-face val
			if with [center-face/with val face]
		]
		view/new val
		val ; unview it later
	]

	req-color: context [
		color-lay: x: t: r: g: b: none
		mods: func [slid clr rgb] [slid/effect/4: poke rgb clr 0 slid/effect/3: poke rgb clr 255]
		refresh: does [
			mods r 1 x/color
			mods g 2 x/color
			mods b 3 x/color
			t/text: x/color
			show [x t r g b]
		]
		setc: func [clr val][
			x/color: poke x/color clr to-integer 255 * (1 - val)
			refresh
		]
		set 'request-color func [
			"Requests a color value."
			/color clr /offset xy /local result
		][
			if none? :color-lay [
				color-lay: layout [
					across origin 5x4 space 8x2
					x: box 80x30 ibevel return
					t: field center middle 80 font-size 10 return
					pad 8
					r: slider 16x278 gray red effect [gradient 0x1 255.0.0 0.0.0] [setc 1 r/data]
					g: slider 16x278 gray green effect [gradient 0x1 0.255.0 0.0.0] [setc 2 g/data]
					b: slider 16x278 gray blue effect [gradient 0x1 0.0.255 0.0.0] [setc 3 b/data]
					return
					pad 8 btn-enter "OK" 64 [result: x/color hide-popup]
					return
					pad 8 btn-cancel "None" escape 64 [hide-popup]
				]
			]
			x/color: either tuple? clr [clr][0.0.0]
			r/data: 1 - (x/color/1 / 255)
			g/data: 1 - (x/color/2 / 255)
			b/data: 1 - (x/color/3 / 255)
			refresh
			either offset [inform/offset color-lay xy][inform color-lay]
			result
		]
	]

	req-pass: context [
		userf: pass: ok: pass-lay: none
		set 'request-pass func [
			"Requests a username and password."
			/offset xy
			/user username
			/only "Password only."
			/title title-text
		][
			if none? user [username: copy ""]
			pass-lay: layout compose [
				style tx text 40x24 middle right
				across origin 10x10 space 2x4
				h3 (either title [title-text][either only ["Enter password:"]["Enter username and password:"]])
				return
				(either only [[]][[tx "User:" userf: field username return]])
				tx "Pass:" pass: field hide [ok: yes hide-popup] with [flags: [return tabbed]] return
				pad 140 
				btn-enter 50 [ok: yes hide-popup]
				btn-cancel 50 #"^(ESC)" [hide-popup]
			]
			ok: no
			focus either only [pass][userf]
			either offset [inform/offset pass-lay xy][inform pass-lay]
			all [ok either only [pass/data][reduce [userf/data pass/data]]]
		]
	]

	req-text: context [
		tf: ok: text-lay: none
		set 'request-text func [
			"Requests a text string be entered."
			/offset xy
			/title title-text
			/default str
		][
			if none? str [str: copy ""]
			text-lay: layout compose [
				across origin 10x10 space 2x4
				h3 bold (either title [title-text]["Enter text below:"])
				return
				tf: field 300 str [ok: yes hide-popup] with [flags: [return]] return
				pad 194
				btn-enter 50 [ok: yes hide-popup]
				btn-cancel 50 #"^(ESC)" [hide-popup]
			]
			ok: no
			focus tf
			either offset [inform/offset text-lay xy][inform text-lay]
			all [ok tf/text]
		]
	]

	req-list: context [
		set 'request-list func [
			"Requests a selection from a list."
			titl [string!]
			alist [block!] /offset xy /local rslt list-lay
		] [
			list-lay: layout [
				;across space 4x8
				origin 10x10
				h3 titl
				text-list data alist [rslt: value hide-popup]
				btn-cancel #"^(ESC)" [rslt: none hide-popup]
			]
			rslt: none
			either offset [inform/offset list-lay xy][inform list-lay]
			rslt
		]
	]

	req-date: context [
		cell-size: 24x24
		result: today: base: date-lay: offs: mo-box: last-f: none
		day-edge: make face/edge [color: sky size: 2x2]

		calc-month: func [month /local slot bas][
			bas: base
			bas/day: slot: 1
			bas/month: month
			foreach face skip date-lay/pane 3 [
				face/edge: none
				either any [slot <= bas/weekday  bas/month <> month][face/text: none][
					if bas/date = today/date [face/edge: day-edge]
					face/text: bas/day  bas: bas + 1
				]
				slot: slot + 1
			]
			show date-lay
		]

		md: func [date] [join pick system/locale/months date/month [" " date/year]]

		init: does [
			date-lay: layout [
				size cell-size * 7
				origin 0x0 space 0
				across
				arrow left cell-size [
					either base/month = 1 [base/year: base/year - 1  base/month: 12][
						base/month: base/month - 1
					]
					mo-box/text: md base  show mo-box
					calc-month base/month
				]
				mo-box: text cell-size * 5x1 md base center middle bold
				arrow right cell-size [base/month: base/month + 1  calc-month base/month  
					mo-box/text: md base  show mo-box]
				return
				offs: at
			]

			last-f: none
			cell-feel: make face/feel [
				over: func [f a] [
					if f/text [f/color: yello show f if last-f [last-f/color: white show last-f]]
					last-f: f
				]
				engage: func [f a e] [
					if all [a = 'down f/text] [base/day: f/text f/color: white result: base hide-popup]
				]
			]

			repeat slot 42 [
				fon: make face/font [valign: 'middle align: 'center]
				append date-lay/pane make face [
					offset: offs  size: cell-size  color: white  edge: none  font: fon
					feel: cell-feel
				]
				offs/x: offs/x + cell-size/x
				if zero? slot // 7 [offs: offs + cell-size * 0x1]
			]
			calc-month base/month
		]

		set 'request-date func [
			"Requests a date."
			/offset xy
			/date when "Default date"
		][
			result: when ; NONE if not set
			base: today: any [when now/date]
			either date-lay [calc-month base/month] [init]
			either offset [inform/offset date-lay xy][inform date-lay]
			result
		]
	]
]

req-file: context [
	dp: p1: ld: dn: s1: lf: fn: s2: p2: ef: p3: so: ob: ff: fp: fcnt: tt: none
	n: n2: m: m2: 0
	si: 1
	files: none
	picked: copy []
	filters: none
	dir-path: %.
	done: none
	out: dirs: none
	filter-list: [["*"]["*.r" "*.reb" "*.rip"]["*.txt"]["*.jpg" "*.gif" "*.bmp" "*.png"]]

	pick-file: func [f] [alter picked f/text  show-pick]

	show-pick: does [
		ef/text: mold picked
		remove ef/text
		remove back tail ef/text
		ef/line-list: none  ; !!! should not be required in simple cases like this!!!
		show ef
	]

	reset-scroll: does [
		m: m2: n: n2: 0
		s1/data: s2/data: 0.0
		show out
	]

	reshow: does [
		clear ef/text
		clear picked
		system/view/focal-face:
		system/view/caret:
		system/view/highlight-start:
		system/view/highlight-end: none
		reset-scroll
	]

	start-out: [
	out: layout [
		across origin 8x8 space 0x4
		style txt txt font-size 11
		style lab text 50x24 middle right bold para [wrap?: no]
		style fld field 336x24 middle font-size 11
		style btn btn 72x24
		style rty rotary 72x24

		tt: h2 "Select a File:" 400x24 left
		return
		lab "Path: "
		dp: fld form what-dir [read-dir/full dp/text reshow]
		p1: at
		;pad -16x2 arrow down 14x20 180.180.180
		return
		lab "Dirs:"

		ld: list 320x72 [
			dn: txt 200x16 [read-dir dn/text reshow]
		] supply [
			count: count + n
			face/text: ""
			face/font/color: black
			if count > length? dirs [return none]
			face/text: pick dirs count
		]
		s1: slider 16x72 [
			n2: to-integer s1/data * ((length? dirs) - (ld/size/y / dn/size/y) + 2)
			if n <> n2 [n: n2 show ld]
		]
		return

		lab "Filters:"
		ff: fld "*" [filters: parse ff/text none  read-dir none reshow]
		pad 6x0
		fp: rty "Normal" "REBOL" "Text" "Images" [
			pick-filter
			read-dir none reshow
		]
		return
		lab "Files:"
		lf: list 320x264 [
			across space 0x0
			fn: txt 120x16
			txt 60x16 right
			txt 75x16 right
			txt 55x16 right 
		] supply [
			fcnt: count: count + m
			face/font/color: black
			face/text: ""
			if count > length? files [return none]
			face/text: do pick [
				[files/:count/1]
				[files/:count/2]
				[all [date? files/:count/3 files/:count/3/date]]
				[all [date? files/:count/3 files/:count/3/time]]
			] index
		]

		s2: slider 16x264 [
			m2: to-integer s2/data * ((length? files) - (lf/size/y / fn/size/y) + 2)
			if m <> m2 [m: m2 show lf]
		]
		p2: at return
		lab "Name:"
		ef: fld [
			if not error? try [picked: parse ef/text none] [
				foreach file picked [if #"%" = first file [remove file]]
				forall picked [change picked to-file first picked]
				picked: unique head picked
				show-pick
			]
		]
		p3: at below at p1 + 6x0
		btn "Parent" [read-dir %.. reshow]
		;btn "Make Dir"
		at p2 + 6x0
		;lab 70 "Sort By:" center
		so: rty "By Name" "Newest" "Oldest" "Largest" "Smallest" [
			si: index? so/data
			sort-files
			reset-scroll
			show lf
		]
		pad 20
		btn "All" [
			clear picked
			foreach file files [append picked first file]
			show-pick
			show lf
		]
		btn "Clear" [clear picked show-pick show lf]
		btn "Refresh" [read-dir none show lf]
		pad 0x40
;does not work, requestor in a requestor bug	btn "Delete" [delete-files read-dir none reshow]
;		btn "Rename"
		at p3 + 6x0
		ob: btn-enter 72x24 "Save" [done: true hide-popup]
		at p3 + 6x-28
		btn-cancel 72x24 "Cancel" [hide-popup]
		across

	]

	deflag-face ef tabbed  ;!!!should be a face option to not tab
	deflag-face dp tabbed

	fn/feel: make fn/feel [
		redraw: func [f a i] [
			f/color: either find picked f/text [240.240.50][240.240.240]
		]
		over: func [f a e] [
			if all [a integer? f/state][
				clear picked
				for n f/state min fcnt length? files either fcnt > f/state [1][-1][
					append picked first pick files n
				]
				show lf
			]
		]
		engage: func [f a e] [
			if a = 'down [
				if fcnt > length? files [exit]
				if not e/control [f/state: fcnt clear picked]
				pick-file f
				show lf
			]
			if a = 'over [if integer? f/state [clear picked append picked f/text show lf]]
			if a = 'up [f/state: none show-pick]
		]
	]

	]

;	find-file: func [name] [foreach item files [if item/1 = name [return item]]]

	filter-files: does [
		while [not tail? files] [
			either foreach filter filters [
				if find/any files/1/1 filter [break/return true]
				false
			][files: next files][remove files]
		]
		files: head files
	]

	pick-filter: does [
		filters: pick filter-list index? fp/data
		ff/text: form filters show ff
	]

	sort-files: does [
		sort/compare files func [a b] pick [
			[a/1 < b/1] ; name
			[a/3 > b/3] ; newest
			[a/3 < b/3] ; oldest
			[a/2 > b/2] ; largest
			[a/2 < b/2] ; smallest
		] si
	]

	delete-files: function [][safe] [
		safe: on
		foreach file picked [
			if safe [
				safe: request [join "Are you sure you want to delete " [dir-path/:file "?"] "Yes" "All" "Cancel"]
				if none? safe [exit]
			]
			error? try [delete dir-path/:file]
		]
	]

	read-dir: func [dir /full /local new-path file-info file] [
		files: []
		show lf 
		if dir [
			new-path: dirize clean-path either full [to-file dir] [dir-path/:dir]
			if exists? new-path [dir-path: new-path]
		]
		dp/text: form dir-path
		if error? try [files: read dir-path][files: copy []]
		dirs: copy []
		while [not tail? files] [
			file: first files
			file: dir-path/:file
			either file-info: info? file [
				either file-info/type = 'directory [append dirs first files remove files]
					[change/only files reduce [files/1 file-info/size file-info/date] files: next files]
			] [files: next files]
		]
		dirs: sort dirs
		files: head files
		m: m2: n: n2: 0
		s1/data: 0.0
		s2/data: 0.0
		s1/redrag (ld/size/y / dn/size/y) / max 1 length? dirs 
		s2/redrag (lf/size/y / fn/size/y) / max 1 length? files
		filter-files
		sort-files
	]

	set 'request-file func [
		"Requests a file using a popup list of files and directories."
		/title "Change heading on request."
			title-line "Title line of request"
			button-text "Button text for selection"
		/file name "Default file name or block of file names"
		/filter filt "Filter or block of filters"
		/keep "Keep previous settings and results"
		/only "Return only a single file, not a block."
		/path "Return absolute path followed by relative files."
		/save "Request file for saving, otherwise loading."
		/local where data filt-names filt-values
	][
		if none? out start-out
		either file [ ; Otherise uses previous value
			either block? name [picked: copy name][picked: reduce [to-file name]]
		][
			if not keep [picked: copy []]
		]
		if none? picked [picked: copy []]
		if file: picked/1 [where: first split-path file]
		while [not tail? picked] [	; remove any files not in the path
			set [name file] split-path first picked
			either name <> where [remove picked][
				change picked file
				picked: next picked
			]
		]
		picked: head picked
		if any [not where not exists? where] [where: clean-path %.]
		if not keep [
			fp/data: head fp/data
			so/data: head so/data
			si: 1
		]
		either filter [
			filters: either block? filt [filt][reduce [filt]]
		][if any [not keep not block? filters][pick-filter]]
		ff/text: form filters
		tt/text: either title [copy title-line]["Select a File:"] 
		ob/text: either title [copy button-text]["Select"]

		if all [
			error? done: try [
				filt-names: copy head fp/data
				filt-values: copy filter-list
				either filter [
					insert head filt-names "Custom"
					insert/only filt-values filters
				] [
					filt-names: at filt-names index? fp/data
				]
				done: local-request-file data: reduce
					[tt/text ob/text clean-path where picked filt-names filt-values found? any [only] found? any [save]]
				if done [
					dir-path: data/3
					picked: data/4
					if not filter [fp/data: at head fp/data index? data/5]
				]
				done
			]
			(get in disarm done 'code) = 328	; RE_FEATURE_NA
		] [
			done: false
			read-dir/full either where [where][dir-path]
			show-pick
			inform out
			unfocus
		]
		if error? done [done]
		if all [done  picked  any [path not empty? picked]] [
			either path [
				done: insert copy picked copy dir-path
				either only [done/1][head done]
			][
				foreach file picked [insert file dir-path]
				either only [picked/1][picked]
			]
		]
	]
]

req-dir: context [
	dirs: []
	max-dirs:
	cnt: 0
	path:
	last-path:
	f-name:
	f-list:
	f-txt:
	f-slid:
	f-path:
	f-title:
	result:
		none

	show-dir: does [
		dirs: attempt [load dirize path]
		if not dirs [
			path: last-path
			if not dirs: attempt [load dirize path][
				alert reform ["Directory does not exist:" path]
				path: what-dir
				dirs: any [attempt [load path] copy []]
			]
		]
		remove-each file dirs [(last file) <> slash]
		foreach file dirs [remove back tail file]
		sort dirs
		f-name/text: any [attempt [second split-path path] "(Top)"]
		f-path/text: any [attempt [to-local-file path] copy ""]
		f-slid/redrag max-dirs / max 1 length? dirs
		f-slid/data: 0.0
		cnt: 0
		show [f-list f-name f-path f-slid]
	]

	chg-dir: func [file][
		if none? file [exit]
		last-path: path
		path: path/:file
		show-dir
	]

	back-dir: does [
		last-path: copy path
		clear find/last path slash
		show-dir
	]

	dirout: [
		origin 10 space 0
		backeffect base-effect
		f-title: h4 200 para [origin: 0x0]
		pad 4
		f-name: text white bold black 200 "Parent" [back-dir]
		across
		f-list: list 184x200 [
			f-txt: text font-size 11 200 font [colors: [0.0.0 0.0.0]] [chg-dir value]
		] supply [
			count: count + cnt
			face/color: pick [240.240.240 220.220.220] odd? count
			if not block? dirs [dirs: copy []]
			face/text: pick dirs count
		]
		f-slid: scroller 16x200 [
			c: to-integer value * ((length? dirs) - max-dirs)
			if c <> cnt [cnt: c show f-list]
		]
		return
		f-path: field wrap font-size 11 200x40 [
			value: attempt [to-rebol-file f-path/text]
			if all [value exists? value] [path: value show-dir]
		]
		return
		pad 2x3
		btn-enter 65 "Open" [if not empty? trim path [result: dirize path] hide-popup]
		btn 65 "Make Dir" [
			inform center-face dout: layout [
				across
				origin 6
				text 100x24 middle bold "Directory name:" f-idir: field return
				pad 120
				btn-enter 70 "Create" [
					hide-popup
					trim value: f-idir/text
					if not empty? value [
						either attempt [make-dir/deep rejoin [path slash value] true][
							show-dir ;chg-dir value
						][
							alert "Cannot create directory."
						]
					]
				]
				btn-cancel 70 "Cancel" escape [hide-popup]
			] "Make a new directory"
			focus f-idir
		]
		btn-cancel 65 "Cancel" escape [hide-popup]
		at f-name/offset + 180x2
		arrow 20x16 black gold up with [color: none edge: none] [back-dir]
	]

	set 'request-dir func [
		"Requests a directory using a popup list."
		/title "Change heading on request." title-line
		/dir "Set starting directory" where [file!]
		/keep "Keep previous directory path"
		/offset xy
	][
		if block? dirout [
			dirout: layout dirout
			max-dirs: to-integer f-list/size/y - 4 / f-txt/size/y
			center-face dirout
		]
		set-face f-title any [title-line "Select a directory:"]
		if not all [keep path] [
			path: copy either where [clean-path where] [what-dir]
		]
		if all [not empty? path slash = last path][remove back tail path]
		last-path: path
		result: none
		show-dir
		either offset [inform/offset dirout xy][inform dirout]
		result
	]
]

;request-dir