REBOL [
	Title: "REBOL/View Desktop - Emailer"
	Version: 1.0.0
	Author: "Carl Sassenrath"
	Rights: "Copyright REBOL Technologies 1999-2005. All rights reserved."
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

ctx-emailer: context [
	f-to: f-cc: f-from: f-subject: f-msg: none

	;-- Emailer layout:
	lo: [
		backeffect base-effect
		style tx text bold 80x24 right
		style fld field 300x24
		across origin 6x6 space 2x1
		tx "From:"    f-from: fld return
		tx "To:"      f-to: fld return
		tx "CC:"      f-cc: fld return
		tx "Subject:" f-subject: fld return
		tx "Message:" f-msg: area wrap 300x200 return
		below at f-msg/offset + f-msg/size * 0x1 + 5x-82 space 0x4
		btn-enter 80x24 "Send" #"^S" [submit-email]
		btn 80x24 "Clear" [clear-all]
		btn-cancel 80x24 "Close" escape [close-em]
	]

	clear-all: does [
		; Clear emailer fields:
		clear-fields lo
		f-from/text: form any [system/user/email "?"]
		clear f-msg/text
		f-msg/line-list: none
		show lo
		focus f-to
	]

	submit-email: has [sending user err] [
		; Send the email:
		sending: flash "Sending..."
		either error? err: try [
			if empty? f-to/text [error-out-here]
			user: any [attempt [load/all f-to/text] copy []]
			if not empty? f-cc/text [
				append user any [attempt [load/all f-cc/text] []]
			]
			system/user/email: attempt [to-email get-face f-from]
			if not system/schemes/default/host [
				if not system/schemes/default/host: request-text/title
					"Email SMTP server:" [exit]
			]
			send/subject user f-msg/text trim f-subject/text
			true
		][
			unview/only sending
			alert reform ["Error sending email. Check fields and check your network setup.  "
				mold disarm :err]
		][
			unview/only sending
			close-em
			alert "Your email has been sent."
		]
	]

	close-em: does [
		; Close the emailer view:
		unview/only lo
	]

	set 'emailer func [
		"Pops up a quick email sender."
		/to "Specify a target address"
		target [string! email!]
		/subject "Specify a subject line"
		what [string!]
		/local req
	][
		if block? lo [
			lo: layout lo
			center-face lo
			lo/color: 160.180.160
		]
		if not alive? [
			alert "Email cannot be sent when offline."
			exit
		]
		if not all [system/user/email system/schemes/default/host] [
			req: request [{Your email settings are missing from the network preferences.
				Set them now?} "Setup" "Ignore" "Cancel"]
			if none? req [exit]
			if all [req value? 'set-user] [set-user]
		]
		clear-all
		if to [f-to/text: copy target]
		if subject [f-subject/text: copy what]
		focus f-to
		view/new/title lo "Emailer"
	]
]

;alive?: true emailer do-events