REBOL [
	Title: "REBOL/View Desktop - Main Module"
	Version: 1.2.0
	Author: "Carl Sassenrath"
	Rights: "Copyright REBOL Technologies 1999-2005. All rights reserved."
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]


;-- Variables ----------------------------------------------------------------

view-root: what-dir	; base directory for file references
alive?: false		; true when connected to net
;link?: false


;-- Utility Functions --------------------------------------------------------

dbug: func [msg [block! any-string!] /local dbg] [
	if not dbg: user-prefs/debug [exit]
	msg: head insert remold msg "desktop "
	either file? dbg [write/append dbg msg][print msg]
]

;-- View Desktop Modules -----------------------------------------------------

#include %viewtop/prefs.r
#include %viewtop/editor.r
#include %viewtop/emailer.r

ctx-viewtop: [

	;-- File Modules -------------------------------------------------------------

	#include %viewtop/initfiles.r
	#include %viewtop/images.r
	#include %viewtop/window.r
	#include %viewtop/folder.r
	#include %viewtop/icon.r
	#include %viewtop/iconinfo.r
	#include %viewtop/initfiles.r
	#include %viewtop/index.r
	#include %viewtop/launch.r
	#include %viewtop/goto.r
	#include %viewtop/help.r
	#include %viewtop/prefs-gui.r
	#include %viewtop/connect.r

	;-- Initialization -----------------------------------------------------------

	init-desktop: has [product] [
		dbug ["Desktop boot" now]

		windowize-dtw
		dtf-face/user-data: none ; prevents display of prior folder backdrop (on restart)
		resize-dtw
		reskin-dtw dtw-skin
		view/new/options/title dtw-face [resize] "Viewtop"
		detect-dtw
		show-id none
		show-modules
		show-welcome
		init-desktop-files
		load-file-types
		if not exists? ctx-prefs/prefs-file [
			alert "Preferences are not set. Please click the User button and set them."
		]
		show-main-status either user-prefs/auto-connect [
			"Connecting to the Internet..."
		][
			{Working offline. Click "Local" to connect.}
		]
		show-services view-root/desktop/services.r
		if user-prefs/auto-connect [connect-view]
		show-bookmarks view-root/desktop/bookmarks.r
		true
	]

	load-file-types: has [data] [
		; Load the list of desktop filetypes:
		; LOAD/ALL shouldn't be needed anymore
		if error? try [data: load view-root/desktop/filetypes.r][exit]
		;if data/1 = 'rebol [data: skip data 2]
		suffix-map: data ;copy data
	]
]

viewtop: desktop: func [
	"Display the REBOL viewtop"
	url [url! file! any-type!]
	/only "Only if prefs/desktop option says so"
][
	; load-prefs has been done earlier in boot

	if all [only not user-prefs/desktop] [exit]

	system/options/quiet: true
	if block? ctx-viewtop [
		ctx-viewtop: context ctx-viewtop
		bind dtw-keymap ctx-viewtop
	]
	ctx-viewtop/init-desktop
	if value? 'url [ctx-viewtop/show-folder :url]
	do-events
]
