REBOL [
	Title: "REBOL/View Desktop - Main Window Layout"
	Version: 1.0.0
	Author: "Carl Sassenrath"
	Rights: "Copyright REBOL Technologies 1999-2005. All rights reserved."
	; You are free to use, modify, and distribute this software with any
	; REBOL Technologies products as long as the above header, copyright,
	; and this comment remain intact. This software is provided "as is"
	; and without warranties of any kind. In no event shall the owners or
	; contributors be liable for any damages of any kind, even if advised
	; of the possibility of such damage. See license for more information.

	; Please help us to improve this software by contributing changes and
	; fixes via http://www.rebol.com/feedback.html - Thanks!
]

;-- Desktop Layouts ----------------------------------------------------------
;
;	The view desktop is constructed from a layout that contains sublayouts.

dtw-open: true		; window is open, not iconized

;-- Main window:

dtw-top:
dtw-b1:
dtw-sid:
dtw-mid:
dtw-b2:
dtw-bot:
	none

dtw-face: layout [
	origin 0x0 space 0x0
	dtw-top: box 640x24
	dtw-b1:  box 640x1
	dtw-sid: box 0x0 ;[][show-folder-options/top]
	dtw-mid: box 640x400 with [effect: none]
	dtw-b2:  box 640x1
	dtw-bot: box 640x48
]

dtw-sid/pane: []

;-- Menu bar on top:

dtm-logo:
dtm-services:
	none

dtm-face: layout [
	size 640x24 origin 0x0 space 8x0 across
	dtm-logo: image 100x24 logo.gif [toggle-dtw]
	dtm-services: box 20x20
]

dtw-top/pane: dtm-face/pane

;-- Services in menu bar:

dts-proto:
	none

dts-face: layout [
	origin 0x2
	dts-proto: vtext "User" bold center middle [view-prefs]
]

;-- Info bar on bottom:

dti-stat:
dti-info:
	none

dti-face: layout [
	origin 0x0 space 8x0 across
	dti-stat: box 100x48 dtw-skin/status-color
	dti-info: txt bold base-color / 2 middle 440x48 return
]

dtw-bot/pane: dti-face/pane

;-- Progress and status area in info bar:

dtp-progress:
dtp-status:
dtp-what:
	none

dtp-face: layout [
	size 100x48 origin 0x0 space 0
	pad 2
	dtp-progress: progress 100x12 100.100.100 button-color
	dtp-status: vtext 100x14 center font-size 10 "Local" [connect-view]
	dtp-what: txt 100 center font-size 10 [help-view] ;[if not view? [show-express-info]]
]

dti-stat/pane: dtp-face/pane
dtp-progress/show?: no

;-- Startup splash layout:

dte-name:
dte-server:
dte-status:
dte-comps:
dte-msg:
;dte-license:
	none

dte-header-txt: rejoin ["Welcome to REBOL/" system/product "  " poke system/version 4 none]

dte-face: layout [
	across 
	h2 dte-header-txt dtw-skin/base-text-color return
	space 0x0
	style txt text bold right 90 dtw-skin/base-text-color
	txt "User:" 
	dte-name:   text bold 300 dtw-skin/over-text-color  return
;	txt bold right 60 "Server:" dtw-skin/base-text-color
;	dte-server: txt bold 300 dtw-skin/over-text-color  return
	txt "Status:"
	dte-status: text bold 300 dtw-skin/over-text-color  return
;	txt "License:"
;	dte-license: text bold 440x36 dtw-skin/over-text-color 
;		either (system/product = 'view) [[browse http://www.rebol.com/view-sales.html]]['bold]
	return
	txt "Components:"
	dte-comps: text bold 300x300 coal return
	pad 0x4
	dte-msg: box 500x300 return
]

;-- Folder face inside middle:

dtf-icons:
dtf-back:
dtf-path:
dtf-slide:
	none

dtf-face: layout/offset [
	origin 0x0 space 0x8 across
	origin 0x10
	dtf-back: box 24x24 effect [arrow 160.0.0 rotate 270] [back-folder] feel [
		over: func [face act] [face/effect/2: pick [240.0.0 160.0.0] act show face]
	]
	pad 0x1
	dtf-path: box 800x22 [][show-folder-options]
	return
	indent 12
	dtf-icons: box [] [show-folder-options] with [effect: none]
	at dtf-icons/offset + 400x0
	dtf-slide: slider 14x200 [scroll-icons value]

] 0x0

;-- Folder path:

dtg-path:
	none

dtg-face: layout/offset [
	origin 0x1
	dtg-path: h3 font-size 12 800x22 "Path" middle [back-folder]
		font [color: dtw-skin/base-text-color colors: reduce [dtw-skin/base-text-color dtw-skin/over-text-color]]
] 0x0

dtg-face/feel/over: none
dtg-face/color: none
dtf-path/pane: dtg-face

;-- Icons inside of folder:

dtc-icon:
	none

dtc-face: layout/offset [
	origin 0x0
	dtc-icon: icon "none"
] 0x0

dtc-face/color: none

dtc-icon/font: make dtc-icon/font [
	color: dtw-skin/base-text-color
	shadow: none
	colors: [dtw-skin/base-text-color complement dtw-skin/base-text-color]
]

dtf-icons/pane: dtc-face


;-- Desktop Event Handling ---------------------------------------------------

detect-dtw: does [
	; Set up the main window event detection callback function.
	; Handles saving the window position and size, processing special keys,
	; scrolling the icons, and trapping the close to minimize the window.
	; This must be done *after* View on dtw.
	dtw-face/options: [resize]
	dtw-face/feel: make dtw-face/feel [
		detect: func [face event /local code] [
			switch event/type [
				resize [
					if dtw-open [
						resize-dtw
						user-prefs/window-size: dtw-face/size
						ctx-prefs/save-prefs
						show dtw-face
					]
					return true
				]
				offset [
					either dtw-open [
						user-prefs/window-offset: dtw-face/offset
					][
						user-prefs/icon-offset: dtw-face/offset
					]
					ctx-prefs/save-prefs
				]
				key [
					if not code: all [user-prefs/keymap select user-prefs/keymap event/key][
						code: select dtw-keymap event/key
					]
					if code [do code return true]
				]
				scroll-line [page-icons event/offset/y * 16]
				scroll-page [page-icons event/offset/y * dtf-icons/size/y]
				close [
					if any [user-prefs/always-close not dtw-open] [quit]
					toggle-dtw
					return true
				]
			]
			event
		]
	]
]


make-bkg: func [full-size /local user-fx usr-img simple-face][
	; Generates background for folder. Allows use of FULL-SIZE
	; as a variable within the effect block.
	simple-face: make face [
		size: full-size
		font: feel: para: edge: none
	]
	user-fx: copy []
	if dtf-face/user-data [
		if dtf-face/user-data/image [
			usr-img: load-safe-image dtf-face/user-data/image
		]
		append user-fx dtf-face/user-data/effect
	]
	attempt [
		to-image make simple-face [
			color: dtw-skin/main-color
			image: dtw-skin/main-image
			effect: bind compose [
				fit
				(dtw-skin/main-effect)
			] 'full-size
			pane: make simple-face [
				color: all [dtf-face/user-data dtf-face/user-data/color]
				image: usr-img
				effect: bind user-fx 'full-size
			]
		]
	]
]

;-- Desktop Window Management ------------------------------------------------

reskin-dtw: func [skin] [
	; Initialize the skin used for the desktop window:
	dtw-mid/color:  skin/main-color
	dtw-top/color:  any [skin/top-bar-color skin/main-color]
	dtw-bot/color:  any [skin/bottom-bar-color skin/main-color]
	dtw-top/effect: 
	dtw-bot/effect: bar-effect
	dtw-b1/color:   skin/main-color - 100.100.100
	dtw-b2/color:   skin/main-color + 60.60.60
	dtw-sid/image:  skin/side-image
	dtw-sid/color:  skin/side-color
	dtw-sid/effect: skin/side-effect
	dtc-icon/font/colors: skin/base-text-color
	dtg-path/font/colors: reduce [skin/base-text-color complement skin/base-text-color]
	dti-info/font/color: skin/info-text-color
]

resize-dtw: has [size] [
	; Resize the desktop window and its sublayout faces:
	size: dtw-face/size

	dtw-sid/size/y: dtw-mid/size/y: max 0 size/y - dtw-top/size/y - dtw-bot/size/y - 2
	dtw-bot/offset/y: 1 + dtw-b2/offset/y: dtw-mid/offset/y + dtw-mid/size/y

	if size/y > 74 [ ; not iconized
		foreach face dtw-face/pane [face/size/x: size/x]

		dti-info/size/x: size/x - dti-info/offset/x

		dtw-sid/size/x: 100
		dtw-mid/offset/x: 100
		dtw-mid/size/x: size/x - 100

		dtf-face/size: dtw-mid/size
		dtc-face/size: dtf-icons/size: dtf-face/size - dtf-icons/offset
		dtc-face/size/x: dtf-icons/size/x: dtc-face/size/x - dtf-slide/size/x - 4 ;scrollbar width
		dtf-slide/offset/x: dtf-icons/offset/x + dtf-icons/size/x + 5 
		dtf-slide/size/y: dtf-icons/size/y
		last-folder: none  ; force the reevaluation of scrollers
		if value? 'layout-icons [layout-icons dtc-face/pane]
	]
	;generate main background
	dtw-mid/image: make-bkg dtw-mid/size
]

iconize-dtw: does [
	; Switch to the desktop minimized "icon" view:
	unview/only dtw-face
	dtw-face/size: 100x74
	dtw-face/offset: any [user-prefs/icon-offset 30x30]
	dtw-face/offset: min dtw-face/offset system/view/screen-face/size - dtw-face/size
	resize-dtw
	view/new/options/title dtw-face [] "Icon"
	detect-dtw
]

windowize-dtw: does [
	; Switch to the fullsize desktop view:
	dtw-face/size: any [user-prefs/window-size 640x480]
	if not dtw-face/offset: user-prefs/window-offset [center-face dtw-face]
	if dtw-open [
		unview/only dtw-face
		resize-dtw
		view/new/options/title dtw-face [resize] "Viewtop"
		detect-dtw
	]
]

toggle-dtw: does [
	; Toggle between fullsize and icon size views:
;	either dtw-open: not dtw-open [windowize-dtw][iconize-dtw]
	browse http://www.rebol.com
]

;-- Status Indicators --------------------------------------------------------

show-status: func [str] [
	; Show status info.
	if alive? [
		dtp-status/text: str
		show dtp-status
	]
]

show-main-status: func [str] [
	; Change the main status string:
	dti-info/text: dte-status/text: str
	show [dti-info dte-status]
]

tell: func [str] [
	; Show info to user:
	dti-info/text: str
	if system/view/focal-face = dti-info [unfocus]
	show dti-info
]

teller: func [str arg] [
	; Show error to user:
	tell reform ["ERROR -" str any [arg ""]]
]

show-welcome: does [
	; Show the default welcome message. (DT welcome screen fields)
	dte-name/text: user-prefs/name
;	dte-server/text: user-prefs/express
	dtw-mid/pane: dte-face/pane
	show dtw-face
]

show-id: func [str] [
	; Show DT version/server in lower left
	dtp-what/text: either str [copy str][rejoin [system/product " " system/version]]
	show dtp-what
]

show-progress: func [length count /no-status] [
	; Update the progress bar:
	if count >= length [hide dtp-progress show-status "" return true]
	if not no-status [show-status "loading"]
	dtp-progress/data: count / max 1 length
	show dtp-progress
	true
]

hide-progress: does [
	; Hide the progress bar:
	hide dtp-progress
]

show-icons: does [
	; Show the icon view:
	dtw-mid/pane: dtf-face
	show dtw-mid
]

show-path: func [str /local tmp] [
	; Show the folder path:
	dtg-path/text: str
	dtg-path/size/x: 1024
	dtg-path/size/x: either tmp: size-text dtg-path [tmp/x + 20][1]
	show dtg-path
]

scroll-icons: func [value /local slid-y] [
	; Scroll the icon pane face:
	slid-y: negate to-integer (value * (dtf-slide-max - dtf-icons/size/y)) 
	if slid-y <> dtc-face/offset/y [ ; optimize scroll speed
		dtc-face/offset/y: slid-y
		show dtf-icons
	]
]

page-icons: func [y] [
	; Scroll the icon pane by a full page:
	if find dtf-face/pane dtf-slide [
		scroll-icons dtf-slide/data: min 1 max 0 (y / dtf-slide-max + dtf-slide/data)
		show dtf-slide
	]
]

pro-features: [
	; List of /Pro components for show-modules function.
	library crypt dhdsa rsa bignum
	fastcgi mysql oracle odbc ssl
]

show-modules: has [product] [
	; Display module list.
	;;dte-license/text: replace/all any [system/user-license/message copy ""] "*** " ""
	;;if system/user-license/id [dte-license/feel: make dte-license/feel [over: none]]
	dte-comps/text: reform ["Core" system/core]
	product: pick [" " " (Command)"] (system/product = 'view)
	;product: pick [" (View/Pro)" " (Command)"] (system/product = 'view)
	foreach [name comp ignore] system/components [
		append dte-comps/text rejoin [
			newline comp/title " " comp/version
			either find pro-features name [product][""]
		]
	]
]
